@@ -12,7 +12,7 @@
         stop("missing value in d")
     if (is.null(rownames)) 
         rownames <- as.character(1:n)
-    if (row.w == "uniform") {
+    if (any(row.w == "uniform")) {
         row.w <- rep(1, n)
     }
     else {
@@ -29,7 +29,7 @@
     wsqrt <- sqrt(row.w)
     delta <- delta * wsqrt
     delta <- t(t(delta) * wsqrt)
-    eig <- La.eigen(delta, symmetric = TRUE)
+    eig <- eigen(delta, symmetric = TRUE)
     lambda <- eig$values
     w0 <- lambda[n]/lambda[1]
     if (w0 < -tol) 
